@@ -39,10 +39,14 @@
 
 //  Set target version to Windows Server 2008, Windows Vista or higher.
 //  Windows XP (0x0501) is supported but without client & server socket types.
-#ifndef _WIN32_WINNT
+#if !defined _WIN32_WINNT && !defined ZMQ_HAVE_WINDOWS_UWP
 #define _WIN32_WINNT 0x0600
 #endif
 
+#if defined ZMQ_HAVE_WINDOWS_UWP
+#define _WIN32_WINNT _WIN32_WINNT_WIN10 
+#endif
+
 #ifdef __MINGW32__
 //  Require Windows XP or higher with MinGW for getaddrinfo().
 #if(_WIN32_WINNT >= 0x0600)
@@ -81,7 +85,7 @@ struct tcp_keepalive {
 #include <process.h>
 #endif
 
-#if ZMQ_USE_POLL
+#if defined ZMQ_USE_POLL
 static inline int poll(struct pollfd *pfd, unsigned long nfds, int timeout) { return WSAPoll(pfd, nfds, timeout); }
 #endif
 
